==> ginkgocadx_3.6.0.1228.33+dfsg.orig.tar.xz: ginkgocadx-3.6.0.1228.33/src/cadxcore/export/tools/iherramientascore.h <==
#pragma once
/*
*  
*  $Id: iherramientascore.h $
*  Ginkgo CADx Project
*
*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#ifndef ITOOLSCORE_H
#define ITOOLSCORE_H
// UIDs de las herramientas core: Reservado desde 0 a 100;

#define HCore_Pointer                     1
#define HCore_Rule                        3
#define HCore_Angulo                      4
#define HCore_Lupa                        5
#define HCore_Varita                      6
#define HCore_LazoChroma                  7
#define HCore_Elevacion                   8
#define HCore_Nota                        9
#define HCore_Deshacer                    10
#define HCore_WindowLayout                11
#define HCore_EdicionDICOM                12
#define HCore_Calibrado                   13
#define HCore_Debug                       14
#define HCore_Marcado                     15
#define HCore_MetricGrid                  16
#define HCore_CornerAnnotations           17
#define HCore_PanelTags                   18
#define HCore_Reset                       19
#define HCore_DetachWindow                20
#define HCore_PixelsBluring               21
#define HCore_SecondaryCapture            22

#define HCore_Pan                         23
#define HCore_Zoom                        24
#define HCore_Slider                      25
#define HCore_WindowLevel                 26

#define HCore_Anonymize                   27
#define HCore_ShowDicomTagsHistory        28
#define HCore_OpenFile                    29
#define HCore_OpenFolder                  30
#define HCore_OpenRemovable               31
#define HCore_DicomizeFromHistory         32
#define HCore_QueryRetrieveHistory        33
#define HCore_HistoryPACSUpload           34
#define HCore_ExportDicomDir              35
#define HCore_ShowDicomTags               36
#define HCore_RotateAndFlip               37
#define HCore_ColorMap                    38
#define HCore_ShowHistory                 39
#define HCore_ImageExport                 40
#define HCore_ImagePrint                  41

#define HCore_Trackball                   42
#define HCore_Video	                      43

#define HCore_PACSUpload                  44
#define HCore_DicomizeFromView            45
#define HCore_AddFileToHistory            46

#define HCore_OpenGinkgoCloudLinkHistory  47
#define HCore_SearchGinkgoCloudHistory    48
#define HCore_CopyImageToClipboard        49

#define HCore_QueryRetrieve               50
#define HCore_CameraRotation              51
#define HCore_BrightnessContrast          52


#define SubFamiliaEdicionDeshacer        0

#endif

==> ginkgocadx_3.7.0.1465.37+dfsg.orig.tar.xz: ginkgocadx-3.7.0.1465.37/src/cadxcore/export/tools/iherramientascore.h <==
#pragma once
/*
*  
*  $Id: iherramientascore.h $
*  Ginkgo CADx Project
*
*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#ifndef ITOOLSCORE_H
#define ITOOLSCORE_H
// UIDs de las herramientas core: Reservado desde 0 a 100;

#define HCore_Pointer                     1
#define HCore_Rule                        3
#define HCore_Angulo                      4
#define HCore_Lupa                        5
#define HCore_Varita                      6
#define HCore_LazoChroma                  7
#define HCore_Elevacion                   8
#define HCore_Nota                        9
#define HCore_Deshacer                    10
#define HCore_WindowLayout                11
#define HCore_EdicionDICOM                12
#define HCore_Calibrado                   13
#define HCore_Debug                       14
#define HCore_Marcado                     15
#define HCore_MetricGrid                  16
#define HCore_CornerAnnotations           17
#define HCore_PanelTags                   18
#define HCore_Reset                       19
#define HCore_DetachWindow                20
#define HCore_PixelsBluring               21
#define HCore_SecondaryCapture            22

#define HCore_Pan                         23
#define HCore_Zoom                        24
#define HCore_Slider                      25
#define HCore_WindowLevel                 26

#define HCore_Anonymize                   27
#define HCore_ShowDicomTagsHistory        28
#define HCore_OpenFile                    29
#define HCore_OpenFolder                  30
#define HCore_OpenRemovable               31
#define HCore_DicomizeFromHistory         32
#define HCore_QueryRetrieveHistory        33
#define HCore_HistoryPACSUpload           34
#define HCore_ExportDicomDir              35
#define HCore_ShowDicomTags               36
#define HCore_RotateAndFlip               37
#define HCore_ColorMap                    38
#define HCore_ShowHistory                 39
#define HCore_ImageExport                 40
#define HCore_SimplePrint                 41

#define HCore_Trackball                   42
#define HCore_Video	                      43

#define HCore_PACSUpload                  44
#define HCore_DicomizeFromView            45
#define HCore_AddFileToHistory            46

#define HCore_OpenGinkgoCloudLinkHistory  47
#define HCore_SearchGinkgoCloudHistory    48
#define HCore_CopyImageToClipboard        49

#define HCore_QueryRetrieve               50
#define HCore_CameraRotation              51
#define HCore_BrightnessContrast          52


#define SubFamiliaEdicionDeshacer        0

#endif
